@@ -43,7 +43,7 @@ else:
 # `declare_component` and call it done. The wrapper allows us to customize
 # our component's API: we can pre-process its input args, post-process its
 # output value, and add a docstring for users.
-def search_bar(subtext, suggestions=None, value=None, key=None):
+def search_bar(subtext, suggestions=None, value=None, width="93%", key=None):
 
     # Call through to our private component function. Arguments we pass here
     # will be sent to the frontend, where they'll be available in an "args"
@@ -53,7 +53,7 @@ def search_bar(subtext, suggestions=None, value=None, key=None):
     # value of the component before the user has interacted with it.
     component_value = _component_func(
         subtext=subtext, suggestions=suggestions,
-        value=value, key=key
+        value=value, width=width, key=key
     )
 
     # We could modify the value returned from the component if we wanted.
@@ -82,5 +82,5 @@ if not _RELEASE:
 
     # Create an instance of our component with a constant `name` arg, and
     # print its output value.
-    search = search_bar("World", ["Test", "amount", "hi", "asklndaklsnd"])
+    search = search_bar("World", ["Test", "amount", "hi", "asklndaklsnd"], width="92%")
     st.markdown("<h1 style='text-align: center'>You've searched for: " + str(search) + "</h1>", unsafe_allow_html=True)
